/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 09043
 |          POLICY RESEARCH ON AGING AND MENTAL HEALTH SERVICES
 |                            (PRAMHS) PROJECT
 |            (DATASET 0001: COMMUNITY MENTAL HEALTH CENTERS)
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\09043-0001-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE caseid    1='(1) Unique identification code'
                  355='(355) Unique identification code' ;
  VALUE v5ffffff  1='(1) Alabama' 2='(2) Alaska' 3='(3) Arizona' 4='(4) Arkansas'
                  5='(5) California' 6='(6) Colorado' 7='(7) Connecticut' 8='(8) Delaware'
                  9='(9) District of Columbia' 10='(10) Florida' 11='(11) Georgia'
                  12='(12) Hawaii' 13='(13) Idaho' 14='(14) Illinois' 15='(15) Indiana' 16='(16) Iowa'
                  17='(17) Kansas' 18='(18) Kentucky' 19='(19) Louisiana' 20='(20) Maine'
                  21='(21) Maryland' 22='(22) Massachusetts' 23='(23) Michigan'
                  24='(24) Minnesota' 25='(25) Mississippi' 26='(26) Missouri' 27='(27) Montana'
                  28='(28) Nebraska' 29='(29) Nevada' 30='(30) New Hampshire'
                  31='(31) New Jersey' 32='(32) New Mexico' 33='(33) New York'
                  34='(34) North Carolina' 35='(35) North Dakota' 36='(36) Ohio'
                  37='(37) Oklahoma' 38='(38) Oregon' 39='(39) Pennsylvania'
                  40='(40) Rhode Island' 41='(41) South Carolina' 42='(42) South Dakota'
                  43='(43) Tennessee' 44='(44) Texas' 45='(45) Utah' 46='(46) Vermont'
                  47='(47) Virginia' 48='(48) Washington' 49='(49) West Virginia'
                  50='(50) Wisconsin' 51='(51) Wyoming' 52='(52) American Samoa' 53='(53) Guam'
                  54='(54) Puerto Rico' 55='(55) Virgin Islands' 56='(56) Marianna Islands'
                  57='(57) North Marianna Islands' ;
  VALUE v6ffffff  1='(1) Area Agency on Aging' 2='(2) State Unit on Aging'
                  3='(3) Community Mental Health Centers'
                  4='(4) State Mental Health Agency' ;
  VALUE v7ffffff  1='(1) Agency identification code'
                  919='(919) Agency identification code' ;
  VALUE v8ffffff  1='(1) One year in operation' 61='(61) Sixty one years in operation'
                  99='(99) N/A' ;
  VALUE v9ffffff  1='(1) Private non-profit' 2='(2) State/local governmental agency'
                  3='(3) Other' 9='(9) N/A' ;
  VALUE v10fffff  70='(70) Seventy thousand dollars'
                  121207='(121207) One hundred seventy one thousand' 999999='(999999) N/A' ;
  VALUE v11fffff  0='(0) Less than one percent' 1='(1) One percent' 2='(2) Two percent'
                  3='(3) Three percent' 4='(4) Four percent' 5='(5) Five percent'
                  6='(6) Six percent' ;
  VALUE v12fffff  0='(0) Less than one percent' 70='(70) Seventy percent' ;
  VALUE v13fffff  0='(0) Less than one percent' 45='(45) Forty five percent' ;
  VALUE v14fffff  10='(10) Active client load' 9999='(9999) Active client load'
                  99999='(99999) N/A' ;
  VALUE v15fffff  0='(0) Less than one percent' 46='(46) Forty six percent' 99='(99) N/A' ;
  VALUE v16fffff  0='(0) Less than one percent' 25='(25) Twenty five percent' 99='(99) N/A' ;
  VALUE v17fffff  0='(0) Less than one percent' 20='(20) Twenty percent' 99='(99) N/A' ;
  VALUE v18fffff  0='(0) Less than one percent' 99='(99) Ninety nine percent'
                  999='(999) N/A' ;
  VALUE v19fffff  0='(0) Less than one percent' 99='(99) Ninety nine percent'
                  999='(999) N/A' ;
  VALUE v20fffff  0='(0) Less than one percent' 99='(99) Ninety nine percent'
                  999='(999) N/A' ;
  VALUE v21fffff  1='(1) Yes' 2='(2) No' ;
  VALUE v22fffff  0='(0) No full-time professional staff'
                  999='(999) 999 or more full-time professional staf' 9999='(9999) N/A' ;
  VALUE v23fffff  0='(0) No part-time professional staff'
                  99='(99) 99 or more part-time professional staff' 999='(999) N/A' ;
  VALUE v24fffff  0='(0) No full-time support staff'
                  99='(99) 99 or more full-time support staff' 999='(999) N/A' ;
  VALUE v25fffff  0='(0) No part-time support staff'
                  99='(99) 99 or more part-time support staff' 999='(999) N/A' ;
  VALUE v26fffff  1='(1) Yes' 2='(2) No' ;
  VALUE v27fffff  1='(1) No contact' 2='(2) Less than monthly contact'
                  3='(3) Monthly contact' 4='(4) Weekly contact' 9='(9) N/A' ;
  VALUE v28fffff  1='(1) Yes' 2='(2) No' ;
  VALUE v29fffff  1='(1) Yes' 2='(2) No' ;
  VALUE v30fffff  1='(1) No involvement' 2='(2) Information provision'
                  3='(3) Review and comment by the AAA'
                  4='(4) Joint planning sessions' 9='(9) N/A' ;
  VALUE v31fffff  1='(1) No involvement' 2='(2) Information provision'
                  3='(3) Review and comment by the AAA'
                  4='(4) Joint planning sessions' 9='(9) N/A' ;
  VALUE v32fffff  1='(1) Yes' 2='(2) No' 8='(8) Don''t know' 9='(9) N/A' ;
  VALUE v33fffff  0='(0) Less than one percent' 56='(56) Fifty six percent' 99='(99) N/A' ;
  VALUE v34fffff  1='(1) Yes' 2='(2) No' ;
  VALUE v35fffff  1='(1) Not at all aware' 2='(2) To a limited extent'
                  3='(3) To a moderate extent' 4='(4) To a great extent' 9='(9) N/A' ;
  VALUE v36fffff  1='(1) Not responsive' 2='(2) Moderately responsive'
                  3='(3) Very responsive' 9='(9) N/A' ;
  VALUE v37fffff  1='(1) MA/MS Gerontology' 2='(2) MSW' 3='(3) R.N.' 4='(4) MA/MS other'
                  5='(5) Ph.D. related field' 6='(6) Ph.D. other'
                  7='(7) BA/BS related field' 8='(8) BA/BS other'
                  9='(9) Other/Psychiatrists' 99='(99) N/A' ;
  VALUE v38fffff  9='(9) N/A' ;
  VALUE v39fffff  1='(1) Lack of information' 9='(9) N/A' ;
  VALUE v40fffff  2='(2) Insufficient funds' 9='(9) N/A' ;
  VALUE v41fffff  3='(3) Limited skills' 9='(9) N/A' ;
  VALUE v42fffff  4='(4) Others factors' 9='(9) N/A' ;
  VALUE v43fffff  1='(1) None' 2='(2) Lobbying' 3='(3) Public hearings'
                  4='(4) Advocacy groups/formal organizations' 9='(9) N/A' ;
  VALUE v44fffff  1='(1) Yes' 2='(2) No' ;
  VALUE v45fffff  1='(1) Informal, personal relations'
                  2='(2) Attitudes, awareness, interest'
                  3='(3) Knowledge and information' 4='(4) Stability-turnover'
                  5='(5) Time and resources' 6='(6) Training' 9='(9) N/A' ;
  VALUE v46fffff  1='(1) Informal, personal relations'
                  2='(2) Attitudes, awareness, interest'
                  3='(3) Knowledge and information' 4='(4) Stability-turnover'
                  5='(5) Time and resources' 6='(6) Training' 9='(9) N/A' ;
  VALUE v47fffff  1='(1) Informal, personal relations'
                  2='(2) Attitudes, awareness, interest'
                  3='(3) Knowledge and information' 4='(4) Stability-turnover'
                  5='(5) Time and resources' 6='(6) Training' 9='(9) N/A' ;
  VALUE v48fffff  1='(1) Funding sources differ'
                  2='(2) Lack of resources-mismanagement'
                  3='(3) Contract for services' 4='(4) OAA does not fund MH services'
                  9='(9) N/A' ;
  VALUE v49fffff  1='(1) Funding sources differ'
                  2='(2) Lack of resources-mismanagement'
                  3='(3) Contract for services' 4='(4) OAA does not fund MH services'
                  9='(9) N/A' ;
  VALUE v50fffff  1='(1) Funding sources differ'
                  2='(2) Lack of resources-mismanagement'
                  3='(3) Contract for services' 4='(4) OAA does not fund MH services'
                  9='(9) N/A' ;
  VALUE v51fffff  1='(1) Medical Model vs. Social Services Model'
                  2='(2) Higher level decisions' 3='(3) Confidentiality'
                  4='(4) MH lack of outreach'
                  5='(5) Either MH or elderly not priority'
                  6='(6) Good intentions-anticipated' 9='(9) N/A' ;
  VALUE v52fffff  1='(1) Medical Model vs. Social Services Model'
                  2='(2) Higher level decisions' 3='(3) Confidentiality'
                  4='(4) MH lack of outreach'
                  5='(5) Either MH or elderly not priority'
                  6='(6) Good intentions-anticipated' 9='(9) N/A' ;
  VALUE v53fffff  1='(1) Medical Model vs. Social Services Model'
                  2='(2) Higher level decisions' 3='(3) Confidentiality'
                  4='(4) MH lack of outreach'
                  5='(5) Either MH or elderly not priority'
                  6='(6) Good intentions-anticipated' 9='(9) N/A' ;
  VALUE v54fffff  1='(1) Communications (contact) not routine'
                  2='(2) Organization Competition' 3='(3) Formal linkages'
                  4='(4) Newness of agency' 5='(5) Proximity co-location'
                  6='(6) Other (agency closed CMHC)' 9='(9) N/A' ;
  VALUE v55fffff  1='(1) Communications (contact) not routine'
                  2='(2) Organization Competition' 3='(3) Formal linkages'
                  4='(4) Newness of agency' 5='(5) Proximity co-location'
                  6='(6) Other (agency closed CMHC)' 9='(9) N/A' ;
  VALUE v56fffff  1='(1) Communications (contact) not routine'
                  2='(2) Organization Competition' 3='(3) Formal linkages'
                  4='(4) Newness of agency' 5='(5) Proximity co-location'
                  6='(6) Other (agency closed CMHC)' 9='(9) N/A' ;
  VALUE v57fffff  1='(1) Stigma of mental illness' 2='(2) Stigma of elderly'
                  3='(3) Elderly powerless and unorganized'
                  4='(4) Other (community disinterest)' 9='(9) N/A' ;
  VALUE v58fffff  1='(1) Stigma of mental illness' 2='(2) Stigma of elderly'
                  3='(3) Elderly powerless and unorganized'
                  4='(4) Other (community disinterest)' 9='(9) N/A' ;
  VALUE v59fffff  1='(1) Stigma of mental illness' 2='(2) Stigma of elderly'
                  3='(3) Elderly powerless and unorganized'
                  4='(4) Other (community disinterest)' 9='(9) N/A' ;
  VALUE v60fffff  1='(1) Homemaker' 2='(2) Nutrition (inc: home delivered meals)'
                  3='(3) Transportation (escort service)'
                  4='(4) Case finding-outreach' 5='(5) Information-referral'
                  6='(6) Legal services' 7='(7) Case management (advocacy)' 8='(8) Other'
                  9='(9) N/A' ;
  VALUE v61fffff  1='(1) Homemaker' 2='(2) Nutrition (inc: home delivered meals)'
                  3='(3) Transportation (escort service)'
                  4='(4) Case finding-outreach' 5='(5) Information-referral'
                  6='(6) Legal services' 7='(7) Case management (advocacy)' 8='(8) Other'
                  9='(9) N/A' ;
  VALUE v62fffff  1='(1) Homemaker' 2='(2) Nutrition (inc: home delivered meals)'
                  3='(3) Transportation (escort service)'
                  4='(4) Case finding-outreach' 5='(5) Information-referral'
                  6='(6) Legal services' 7='(7) Case management (advocacy)' 8='(8) Other'
                  9='(9) N/A' ;
  VALUE v63fffff  1='(1) Homemaker' 2='(2) Nutrition (inc: home delivered meals)'
                  3='(3) Transportation (escort service)'
                  4='(4) Case finding-outreach' 5='(5) Information-referral'
                  6='(6) Legal services' 7='(7) Case management (advocacy)' 8='(8) Other'
                  9='(9) N/A' ;
  VALUE v64fffff  1='(1) Training-geriatric personnel' 2='(2) Training-volunteers'
                  3='(3) Preretirement-education' 4='(4) Post-retirement education'
                  5='(5) Groups: Socialization, Activity' 6='(6) Crime prevention'
                  7='(7) Creative arts' 8='(8) Benefits counseling (educ.)'
                  9='(9) Other(general C-E, community ed.)' 99='(99) N/A' ;
  VALUE v65fffff  1='(1) Training-geriatric personnel' 2='(2) Training-volunteers'
                  3='(3) Preretirement-education' 4='(4) Post-retirement education'
                  5='(5) Groups: Socialization, Activity' 6='(6) Crime prevention'
                  7='(7) Creative arts' 8='(8) Benefits counseling (educ.)'
                  9='(9) Other(general C-E, community ed.)' 99='(99) N/A' ;
  VALUE v66fffff  1='(1) Training-geriatric personnel' 2='(2) Training-volunteers'
                  3='(3) Preretirement-education' 4='(4) Post-retirement education'
                  5='(5) Groups: Socialization, Activity' 6='(6) Crime prevention'
                  7='(7) Creative arts' 8='(8) Benefits counseling (educ.)'
                  9='(9) Other(general C-E, community ed.)' 99='(99) N/A' ;
  VALUE v67fffff  1='(1) Training-geriatric personnel' 2='(2) Training-volunteers'
                  3='(3) Preretirement-education' 4='(4) Post-retirement education'
                  5='(5) Groups: Socialization, Activity' 6='(6) Crime prevention'
                  7='(7) Creative arts' 8='(8) Benefits counseling (educ.)'
                  9='(9) Other(general C-E, community ed.)' 99='(99) N/A' ;
  VALUE v68fffff  1='(1) Nursing home visits' 2='(2) Geriatric evaluation team'
                  3='(3) In-patient screening diagnosis'
                  4='(4) Hypertension screening'
                  5='(5) Other (comprehensive assessment)' 9='(9) N/A' ;
  VALUE v69fffff  1='(1) Nursing home visits' 2='(2) Geriatric evaluation team'
                  3='(3) In-patient screening diagnosis'
                  4='(4) Hypertension screening'
                  5='(5) Other (comprehensive assessment)' 9='(9) N/A' ;
  VALUE v70fffff  1='(1) Home visits' 2='(2) Telephone reassurance' 3='(3) Senior visits'
                  4='(4) Other (placement, group homes)' 9='(9) N/A' ;
  VALUE v71fffff  1='(1) Home visits' 2='(2) Telephone reassurance' 3='(3) Senior visits'
                  4='(4) Other (placement, group homes)' 9='(9) N/A' ;
  VALUE v72fffff  1='(1) Home visits' 2='(2) Telephone reassurance' 3='(3) Senior visits'
                  4='(4) Other (placement, group homes)' 9='(9) N/A' ;
  VALUE v73fffff  1='(1) Nursing home visits-therapy' 2='(2) Respite'
                  3='(3) Inpatient (hospital institution)' 9='(9) N/A' ;
  VALUE v74fffff  1='(1) Nursing home visits-therapy' 2='(2) Respite'
                  3='(3) Inpatient (hospital institution)' 9='(9) N/A' ;
  VALUE v75fffff  1='(1) Nursing home visits-therapy' 2='(2) Respite'
                  3='(3) Inpatient (hospital institution)' 9='(9) N/A' ;
  VALUE v76fffff  1='(1) Follow-up and aftercare' 2='(2) Reality orientation OBS'
                  3='(3) Victim assistance' 4='(4) Grief support' 5='(5) Counseling-GP'
                  6='(6) Crisis intervention' 7='(7) Partial hospitalization'
                  8='(8) Other (chemotherapy, etc.)' 9='(9) N/A' ;
  VALUE v77fffff  1='(1) Follow-up and aftercare' 2='(2) Reality orientation OBS'
                  3='(3) Victim assistance' 4='(4) Grief support' 5='(5) Counseling-GP'
                  6='(6) Crisis intervention' 7='(7) Partial hospitalization'
                  8='(8) Other (chemotherapy, etc.)' 9='(9) N/A' ;
  VALUE v78fffff  1='(1) Follow-up and aftercare' 2='(2) Reality orientation OBS'
                  3='(3) Victim assistance' 4='(4) Grief support' 5='(5) Counseling-GP'
                  6='(6) Crisis intervention' 7='(7) Partial hospitalization'
                  8='(8) Other (chemotherapy, etc.)' 9='(9) N/A' ;
  VALUE v79fffff  1='(1) Follow-up and aftercare' 2='(2) Reality orientation OBS'
                  3='(3) Victim assistance' 4='(4) Grief support' 5='(5) Counseling-GP'
                  6='(6) Crisis intervention' 7='(7) Partial hospitalization'
                  8='(8) Other (chemotherapy, etc.)' 9='(9) N/A' ;
  VALUE v80fffff  1='(1) Follow-up and aftercare' 2='(2) Reality orientation OBS'
                  3='(3) Victim assistance' 4='(4) Grief support' 5='(5) Counseling-GP'
                  6='(6) Crisis intervention' 7='(7) Partial hospitalization'
                  8='(8) Other (chemotherapy, etc.)' 9='(9) N/A' ;
  VALUE v81fffff  0='(0) No fulltime psychiatrists'
                  22='(22) Twenty two fulltime psychiatrists' 999='(999) N/A' ;
  VALUE v82fffff  0='(0) No fulltime psychologist' 43='(43) Forty three psychologists'
                  99='(99) N/A' ;
  VALUE v83fffff  0='(0) No fulltime social worker'
                  35='(35) Thirty five fulltime social workers' 99='(99) N/A' ;
  VALUE v84fffff  0='(0) No fulltime administrative staff'
                  28='(28) Twenty eight fulltime admistrative staf' 99='(99) N/A' ;
  VALUE v85fffff  13='(13) Thirteen fulltime staff agency'
                  393='(393) Three hundred ninety three fulltime sta' 999='(999) N/A' ;
  VALUE v86fffff  0='(0) Zero hours' 99='(99) Ninety nine hours' 999='(999) N/A' ;
  VALUE v87fffff  0='(0) Zero hours' 432='(432) Four hundred thirty two hours'
                  999='(999) N/A' ;
  VALUE v88fffff  0='(0) Zero hours' 281='(281) Two hundred eighty one hours' 999='(999) N/A' ;
  VALUE v89fffff  0='(0) Zero hours' 205='(205) Two hundred five hours' 999='(999) N/A' ;
  VALUE v90fffff  1='(1) Yes/no' 2='(2) No/no' 3='(3) Yes/yes' 9='(9) N/A' ;
  VALUE v91fffff  1='(1) Incongruent by 3' 2='(2) Incongruent by 2'
                  3='(3) Incongruent by 1' 4='(4) Both answered not at all'
                  5='(5) Both answered to a limited extent'
                  6='(6) Both answered to a moderate extent'
                  7='(7) Both answered to a great extent' 9='(9) N/A' ;
  VALUE v92fffff  1='(1) Yes/no' 2='(2) No/no' 3='(3) Yes/yes' 9='(9) N/A' ;
  VALUE v93fffff  1='(1) Incongruent by 2' 2='(2) Incongruent by 1'
                  3='(3) Both answered not at all'
                  4='(4) Both answered moderately responsive'
                  5='(5) Both answered very responsive' 9='(9) N/A' ;
  VALUE v94fffff  1='(1) Incongruent by 3' 2='(2) Incongruent by 2'
                  3='(3) Incongruent by 1' 4='(4) Both answered no contact'
                  5='(5) Both answered less than monthly'
                  6='(6) Both answered monthly' 7='(7) Both answered weekly' 9='(9) N/A' ;
  VALUE v95fffff  1='(1) Incongruent by 3' 2='(2) Incongruent by 2'
                  3='(3) Incongruent by 1' 4='(4) Both answered no involvement'
                  5='(5) Both answered information'
                  6='(6) Both answered review and comment'
                  7='(7) Both answered joint planning sessions' 9='(9) N/A' ;
  VALUE v96fffff  1='(1) Incongruent by 3' 2='(2) Incongruent by 2'
                  3='(3) incongruent by 1' 4='(4) Both answered no involvement'
                  5='(5) Both answered information'
                  6='(6) Both answered review and comment'
                  7='(7) Both answered joint planning sessions' 9='(9) N/A' ;
  VALUE v97fffff  157623='(157623) Total expenditure in dollars'
                  9145891='(9145891) Total expenditure in dollars' 9999999='(9999999) N/A' ;
  VALUE v98fffff  0='(0) No funding' 4254066='(4254066) State funding in dollars'
                  9999999='(9999999) N/A' ;
  VALUE v99fffff  0='(0) No funding'
                  2622319='(2622319) Local government funding in dollars' 9999999='(9999999) N/A' ;
  VALUE v100ffff  0='(0) No funding'
                  4621245='(4621245) Total government funding in dollars' 9999999='(9999999) N/A' ;
  VALUE v101ffff  0='(0) No funding' 434491='(434491) Funds collected from Medicare'
                  999999='(999999) N/A' ;
  VALUE v102ffff  0='(0) No funding' 938506='(938506) Funds collected as patient fees'
                  999999='(999999) N/A' ;
  VALUE v103ffff  0='(0) No funding' 2027076='(2027076) Funds collected from insurance'
                  9999999='(9999999) N/A' ;
  VALUE v104ffff  0='(0) No funding' 7332169='(7332169) Funds collected from Medicaid'
                  9999999='(9999999) N/A' ;
  VALUE v105ffff  1='(1) One receipt collected'
                  4353265='(4353265) Amount of total receipts collected' 9999999='(9999999) N/A' ;
  VALUE v106ffff  157623='(157623) Amount of total receipts collected'
                  8548463='(8548463) Amount of total receipts collected' 9999999='(9999999) N/A' ;
  VALUE v107ffff  144='(144) Count of persons' 5924='(5924) Count of persons' 9999='(9999) N/A' ;
  VALUE v108ffff  39='(39) Persons on center''s caseload'
                  7289='(7289) Persons on center''s caseload' 9999='(9999) N/A' ;
  VALUE v109ffff  0='(0) No home visits' 8105='(8105) Home visits' 9999='(9999) N/A' ;
  VALUE v110ffff  0='(0) None' 2223='(2223) Number of inpatient care episodes'
                  9999='(9999) N/A' ;
  VALUE v111ffff  0='(0) None' 9999='(9999) Number of outpatient care episodes'
                  99999='(99999) N/A' ;
  VALUE v112ffff  0='(0) None' 201='(201) Number diagnosed as Organic Brain Syndr'
                  999='(999) N/A' ;
  VALUE v113ffff  0='(0) None' 374='(374) Number of additions age 65 or older'
                  999='(999) N/A' ;
  VALUE v114ffff  0='(0) None' 998='(998) Number of additions age 45-64' 999='(999) Not' ;
  VALUE v115ffff  0='(0) None' 999='(999) Number of referrals from social/comm ag'
                  9999='(9999) N/A' ;
  VALUE v116ffff  0='(0) None' 150='(150) Number of people referred to nursing ho'
                  999='(999) N/A' ;
  VALUE v117ffff  0='(0) None' 721='(721) Number of people referred to social/com'
                  999='(999) N/A' ;
  VALUE v118ffff  1937='(1937) Number of persons of age 65 and over'
                  60281='(60281) Number of persons of age 65 and over' 99999='(99999) N/A' ;
  VALUE v119ffff  1='(1) Low' 2='(2) Low' 3='(3) Low' 4='(4) High' 5='(5) High' 6='(6) High' 9='(9) N/A' ;
  VALUE v120ffff  11='(11) Metropolitan' 13='(13) Metropolitan' 24='(24) Mixed' 26='(26) Mixed'
                  37='(37) Non-metropolitan' 39='(39) Non-metropolitan' 99='(99) N/A' ;
  VALUE v121ffff  0='(0) Zero percent' 10='(10) Ten percent' 99='(99) N/A' ;
  VALUE v122ffff  3972='(3972) Number of white males' 99093='(99093) Number of white males'
                  99999='(99999) N/A' ;
  VALUE v123ffff  69='(69) Number of non-white males'
                  88681='(88681) Number of non-white males' 99999='(99999) N/A' ;
  VALUE v124ffff  3761='(3761) Number of white females'
                  97067='(97067) Number of white females' 99999='(99999) N/A' ;
  VALUE v125ffff  67='(67) Number of non-white females'
                  98441='(98441) Number of non-white females' 99999='(99999) N/A' ;
  VALUE v126ffff  15731='(15731) Total population of catchment area'
                  96193='(96193) Total population of catchment area' 99999='(99999) N/A' ;
  VALUE v127ffff  0='(0) Zero' 9='(9) N/A' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=295;
INPUT
        CASEID 1-3              V5 4-5                  V6 6
        V7 7-9                  V8 10-11                V9 12
        V10 13-18               V11 19                  V12 20-21
        V13 22-23               V14 24-28               V15 29-30
        V16 31-32               V17 33-34               V18 35-37
        V19 38-40               V20 41-43               V21 44
        V22 45-48               V23 49-51               V24 52-54
        V25 55-57               V26 58                  V27 59
        V28 60                  V29 61                  V30 62
        V31 63                  V32 64                  V33 65-66
        V34 67                  V35 68                  V36 69
        V37 70-71               V38 72-73               V39 74
        V40 75                  V41 76                  V42 77
        V43 78                  V44 79                  V45 80
        V46 81                  V47 82                  V48 83
        V49 84                  V50 85                  V51 86
        V52 87                  V53 88                  V54 89
        V55 90                  V56 91                  V57 92
        V58 93                  V59 94                  V60 95
        V61 96                  V62 97                  V63 98
        V64 99-100              V65 101-102             V66 103-104
        V67 105-106             V68 107                 V69 108
        V70 109                 V71 110                 V72 111
        V73 112                 V74 113                 V75 114
        V76 115                 V77 116                 V78 117
        V79 118                 V80 119                 V81 120-122
        V82 123-124             V83 125-126             V84 127-128
        V85 129-131             V86 132-134             V87 135-137
        V88 138-140             V89 141-143             V90 144
        V91 145                 V92 146                 V93 147
        V94 148                 V95 149                 V96 150
        V97 151-157             V98 158-164             V99 165-171
        V100 172-178            V101 179-184            V102 185-190
        V103 191-197            V104 198-204            V105 205-211
        V106 212-218            V107 219-222            V108 223-226
        V109 227-230            V110 231-234            V111 235-239
        V112 240-242            V113 243-245            V114 246-249
        V115 250-253            V116 254-256            V117 257-259
        V118 260-264            V119 265                V120 266-267
        V121 268-269            V122 270-274            V123 275-279
        V124 280-284            V125 285-289            V126 290-294
        V127 295                ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'ICPSR SEQUENTIAL CASE ID NUMBER'
   V5      = 'STCODE'
   V6      = 'SRVCODE'
   V7      = 'AGENCY'
   V8      = 'YRS'
   V9      = 'CMHCOP'
   V10     = 'BUDGET'
   V11     = 'OAA'
   V12     = 'SSA'
   V13     = 'BGTESV'
   V14     = 'TLOAD'
   V15     = 'CLIENTA'
   V16     = 'CLIENTB'
   V17     = 'CLIENTC'
   V18     = 'MEDSA'
   V19     = 'MEDSB'
   V20     = 'MEDSC'
   V21     = 'COORESV'
   V22     = 'SPFT'
   V23     = 'SPPT'
   V24     = 'SSFT'
   V25     = 'SSPT'
   V26     = 'LAIS'
   V27     = 'FREQCON'
   V28     = 'HSAPC'
   V29     = 'HSAGB'
   V30     = 'CHARAC'
   V31     = 'CHARCA'
   V32     = 'ELINST'
   V33     = 'AGCMHCB'
   V34     = 'SUPTPRG'
   V35     = 'POLAWRE'
   V36     = 'GVTRSP'
   V37     = 'TRNG'
   V38     = 'YREXP'
   V39     = 'SPTLI'
   V40     = 'SPTINF'
   V41     = 'SPTLS'
   V42     = 'SPTOT'
   V43     = 'MECHINF'
   V44     = 'POSINAC'
   V45     = 'STFCHARA'
   V46     = 'STFCHARB'
   V47     = 'STFCHARC'
   V48     = 'ECOFACA'
   V49     = 'ECOFACB'
   V50     = 'ECOFACC'
   V51     = 'POLFACA'
   V52     = 'POLFACB'
   V53     = 'POLFACC'
   V54     = 'SYSFACA'
   V55     = 'SYSFACB'
   V56     = 'SYSFACC'
   V57     = 'SOCISSA'
   V58     = 'SOCISSB'
   V59     = 'SOCISSC'
   V60     = 'SPSVCOTA'
   V61     = 'SPSVCOTB'
   V62     = 'SPCVCOTC'
   V63     = 'SPSVCOTD'
   V64     = 'SPSVCEA'
   V65     = 'SPSVCEB'
   V66     = 'SPSVCEC'
   V67     = 'SPSVCED'
   V68     = 'SPSVAEA'
   V69     = 'SPSVAEB'
   V70     = 'TRMTHMA'
   V71     = 'TRMTHMB'
   V72     = 'TRMTHMC'
   V73     = 'TRMTIPA'
   V74     = 'TRMTIPB'
   V75     = 'TRMTIPC'
   V76     = 'TRMTOPA'
   V77     = 'TRMTOPB'
   V78     = 'TRMTOPC'
   V79     = 'TRMTOPD'
   V80     = 'TRMTOPE'
   V81     = '1976V7'
   V82     = '1976V25'
   V83     = '1976V43'
   V84     = '1976V106'
   V85     = '1976V124'
   V86     = '1976V257'
   V87     = '1976V258'
   V88     = '1976V259'
   V89     = '1976V260'
   V90     = '1976V2018'
   V91     = '1976V2323'
   V92     = '1976V2222'
   V93     = '1976V2525'
   V94     = '1976V1414'
   V95     = '1976V1516'
   V96     = '1976V1617'
   V97     = '1976V304'
   V98     = '1976V311'
   V99     = '1976V312'
   V100    = '1976V314'
   V101    = '1976V317'
   V102    = '1976V315'
   V103    = '1976V316'
   V104    = '1976V318'
   V105    = '1976V321'
   V106    = '1976V327'
   V107    = '1976V330'
   V108    = '1976V332'
   V109    = '1976V364'
   V110    = '1976V335'
   V111    = '1976V355'
   V112    = '1976V390'
   V113    = '1976V455'
   V114    = '1976V450'
   V115    = '1976V548'
   V116    = '1976V558'
   V117    = '1976V559'
   V118    = '1976V897'
   V119    = '1976V892'
   V120    = '1976V893'
   V121    = '1976V894'
   V122    = '1976V898'
   V123    = '1976V899'
   V124    = '1976V900'
   V125    = '1976V901'
   V126    = 'TOTPOP'
   V127    = 'PROP65'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (V8 = 99) THEN V8 = .;
   IF (V9 = 9) THEN V9 = .;
   IF (V10 = 999999) THEN V10 = .;
   IF (V14 = 99999) THEN V14 = .;
   IF (V15 = 99) THEN V15 = .;
   IF (V16 = 99) THEN V16 = .;
   IF (V17 = 99) THEN V17 = .;
   IF (V18 = 999) THEN V18 = .;
   IF (V19 = 999) THEN V19 = .;
   IF (V20 = 999) THEN V20 = .;
   IF (V22 = 9999) THEN V22 = .;
   IF (V23 = 999) THEN V23 = .;
   IF (V24 = 999) THEN V24 = .;
   IF (V25 = 999) THEN V25 = .;
   IF (V27 = 9) THEN V27 = .;
   IF (V30 = 9) THEN V30 = .;
   IF (V31 = 9) THEN V31 = .;
   IF (V32 = 9) THEN V32 = .;
   IF (V33 = 99) THEN V33 = .;
   IF (V35 = 9) THEN V35 = .;
   IF (V36 = 9) THEN V36 = .;
   IF (V37 = 99) THEN V37 = .;
   IF (V38 = 9) THEN V38 = .;
   IF (V39 = 9) THEN V39 = .;
   IF (V40 = 9) THEN V40 = .;
   IF (V41 = 9) THEN V41 = .;
   IF (V42 = 9) THEN V42 = .;
   IF (V43 = 9) THEN V43 = .;
   IF (V45 = 9) THEN V45 = .;
   IF (V46 = 9) THEN V46 = .;
   IF (V47 = 9) THEN V47 = .;
   IF (V48 = 9) THEN V48 = .;
   IF (V49 = 9) THEN V49 = .;
   IF (V50 = 9) THEN V50 = .;
   IF (V51 = 9) THEN V51 = .;
   IF (V52 = 9) THEN V52 = .;
   IF (V53 = 9) THEN V53 = .;
   IF (V54 = 9) THEN V54 = .;
   IF (V55 = 9) THEN V55 = .;
   IF (V56 = 9) THEN V56 = .;
   IF (V57 = 9) THEN V57 = .;
   IF (V58 = 9) THEN V58 = .;
   IF (V59 = 9) THEN V59 = .;
   IF (V60 = 9) THEN V60 = .;
   IF (V61 = 9) THEN V61 = .;
   IF (V62 = 9) THEN V62 = .;
   IF (V63 = 9) THEN V63 = .;
   IF (V64 = 99) THEN V64 = .;
   IF (V65 = 99) THEN V65 = .;
   IF (V66 = 99) THEN V66 = .;
   IF (V67 = 99) THEN V67 = .;
   IF (V68 = 9) THEN V68 = .;
   IF (V69 = 9) THEN V69 = .;
   IF (V70 = 9) THEN V70 = .;
   IF (V71 = 9) THEN V71 = .;
   IF (V72 = 9) THEN V72 = .;
   IF (V73 = 9) THEN V73 = .;
   IF (V74 = 9) THEN V74 = .;
   IF (V75 = 9) THEN V75 = .;
   IF (V76 = 9) THEN V76 = .;
   IF (V77 = 9) THEN V77 = .;
   IF (V78 = 9) THEN V78 = .;
   IF (V79 = 9) THEN V79 = .;
   IF (V80 = 9) THEN V80 = .;
   IF (V81 = 999) THEN V81 = .;
   IF (V82 = 99) THEN V82 = .;
   IF (V83 = 99) THEN V83 = .;
   IF (V84 = 99) THEN V84 = .;
   IF (V85 = 999) THEN V85 = .;
   IF (V86 = 999) THEN V86 = .;
   IF (V87 = 999) THEN V87 = .;
   IF (V88 = 999) THEN V88 = .;
   IF (V89 = 999) THEN V89 = .;
   IF (V90 = 9) THEN V90 = .;
   IF (V91 = 9) THEN V91 = .;
   IF (V92 = 9) THEN V92 = .;
   IF (V93 = 9) THEN V93 = .;
   IF (V94 = 9) THEN V94 = .;
   IF (V95 = 9) THEN V95 = .;
   IF (V96 = 9) THEN V96 = .;
   IF (V97 = 9999999) THEN V97 = .;
   IF (V98 = 9999999) THEN V98 = .;
   IF (V99 = 9999999) THEN V99 = .;
   IF (V100 = 9999999) THEN V100 = .;
   IF (V101 = 999999) THEN V101 = .;
   IF (V102 = 999999) THEN V102 = .;
   IF (V103 = 9999999) THEN V103 = .;
   IF (V104 = 9999999) THEN V104 = .;
   IF (V105 = 9999999) THEN V105 = .;
   IF (V106 = 9999999) THEN V106 = .;
   IF (V107 = 9999) THEN V107 = .;
   IF (V108 = 9999) THEN V108 = .;
   IF (V109 = 9999) THEN V109 = .;
   IF (V110 = 9999) THEN V110 = .;
   IF (V111 = 99999) THEN V111 = .;
   IF (V112 = 999) THEN V112 = .;
   IF (V113 = 999) THEN V113 = .;
   IF (V114 = 9999) THEN V114 = .;
   IF (V115 = 9999) THEN V115 = .;
   IF (V116 = 999) THEN V116 = .;
   IF (V117 = 999) THEN V117 = .;
   IF (V118 = 99999) THEN V118 = .;
   IF (V119 = 9) THEN V119 = .;
   IF (V120 = 99) THEN V120 = .;
   IF (V121 = 99) THEN V121 = .;
   IF (V122 = 99999) THEN V122 = .;
   IF (V123 = 99999) THEN V123 = .;
   IF (V124 = 99999) THEN V124 = .;
   IF (V125 = 99999) THEN V125 = .;
   IF (V126 = 99999) THEN V126 = .;
   IF (V127 = 9) THEN V127 = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT CASEID caseid. V5 v5ffffff. V6 v6ffffff.
         V7 v7ffffff. V8 v8ffffff. V9 v9ffffff.
         V10 v10fffff. V11 v11fffff. V12 v12fffff.
         V13 v13fffff. V14 v14fffff. V15 v15fffff.
         V16 v16fffff. V17 v17fffff. V18 v18fffff.
         V19 v19fffff. V20 v20fffff. V21 v21fffff.
         V22 v22fffff. V23 v23fffff. V24 v24fffff.
         V25 v25fffff. V26 v26fffff. V27 v27fffff.
         V28 v28fffff. V29 v29fffff. V30 v30fffff.
         V31 v31fffff. V32 v32fffff. V33 v33fffff.
         V34 v34fffff. V35 v35fffff. V36 v36fffff.
         V37 v37fffff. V38 v38fffff. V39 v39fffff.
         V40 v40fffff. V41 v41fffff. V42 v42fffff.
         V43 v43fffff. V44 v44fffff. V45 v45fffff.
         V46 v46fffff. V47 v47fffff. V48 v48fffff.
         V49 v49fffff. V50 v50fffff. V51 v51fffff.
         V52 v52fffff. V53 v53fffff. V54 v54fffff.
         V55 v55fffff. V56 v56fffff. V57 v57fffff.
         V58 v58fffff. V59 v59fffff. V60 v60fffff.
         V61 v61fffff. V62 v62fffff. V63 v63fffff.
         V64 v64fffff. V65 v65fffff. V66 v66fffff.
         V67 v67fffff. V68 v68fffff. V69 v69fffff.
         V70 v70fffff. V71 v71fffff. V72 v72fffff.
         V73 v73fffff. V74 v74fffff. V75 v75fffff.
         V76 v76fffff. V77 v77fffff. V78 v78fffff.
         V79 v79fffff. V80 v80fffff. V81 v81fffff.
         V82 v82fffff. V83 v83fffff. V84 v84fffff.
         V85 v85fffff. V86 v86fffff. V87 v87fffff.
         V88 v88fffff. V89 v89fffff. V90 v90fffff.
         V91 v91fffff. V92 v92fffff. V93 v93fffff.
         V94 v94fffff. V95 v95fffff. V96 v96fffff.
         V97 v97fffff. V98 v98fffff. V99 v99fffff.
         V100 v100ffff. V101 v101ffff. V102 v102ffff.
         V103 v103ffff. V104 v104ffff. V105 v105ffff.
         V106 v106ffff. V107 v107ffff. V108 v108ffff.
         V109 v109ffff. V110 v110ffff. V111 v111ffff.
         V112 v112ffff. V113 v113ffff. V114 v114ffff.
         V115 v115ffff. V116 v116ffff. V117 v117ffff.
         V118 v118ffff. V119 v119ffff. V120 v120ffff.
         V121 v121ffff. V122 v122ffff. V123 v123ffff.
         V124 v124ffff. V125 v125ffff. V126 v126ffff.
         V127 v127ffff.  ;
*/

RUN ;
